@@ -131,6 +131,7 @@ class ToolsManager(plugin.PluginsManager, object):
 
                     plugins_found.append((qname, version_found, obj))
                     version_found = True
+                    break
 
         if not plugins_found:
             tp.logger.warning('No plugins found in module "{}". Skipping ...'.format(plugin_name))
@@ -440,7 +441,6 @@ class ToolsManager(plugin.PluginsManager, object):
         :return: DccTool or None, executed tool instance
         """
 
-        from tpDcc.libs.python import importer
         from tpDcc.libs.qt.core import settings
 
         if not package_name:
@@ -478,24 +478,10 @@ class ToolsManager(plugin.PluginsManager, object):
         tool_config = self._plugins[package_name][tool_to_run]['config']
         tool_fullname = tool_loader.fullname if python.is_python2() else tool_loader.loader.name
         tool_version = self._plugins[package_name][tool_to_run]['version']
-        dcc_loader = self._plugins[package_name][tool_to_run]['dcc_loader']
-        dcc_config = self._plugins[package_name][tool_to_run]['dcc_config']
 
         pkg_name = pkg_loader.filename if python.is_python2() else os.path.dirname(pkg_loader.loader.path)
         pkg_path = pkg_loader.fullname if python.is_python2() else pkg_loader.loader.name
 
-        # if tool_config:
-        #     skip_modules = ['{}.{}'.format(pkg_path, mod) for mod in
-        #                     tool_config.data.get('skip_modules', list())]
-        # else:
-        #     skip_modules = list()
-        # importer.init_importer(pkg_path, skip_modules=skip_modules)
-        #
-        # if dcc_loader:
-        #     dcc_skip_modules = ['{}.{}'.format(pkg_path, mod) for mod in
-        #                         dcc_config.data.get('skip_modules', list())]
-        #     importer.init_importer(pkg_path, skip_modules=dcc_skip_modules)
-
         tool_found = None
         for sub_module in pkgutil.walk_packages([self._plugins[package_name][tool_to_run]['plugin_package_path']]):
             tool_importer, sub_module_name, _ = sub_module
